[SCM] WebKit Debian packaging branch, webkit-1.1, updated. upstream/1.1.21-584-g1e41756

eric at webkit.org eric at webkit.org
Fri Feb 26 22:25:53 UTC 2010


The following commit has been merged in the webkit-1.1 branch:
commit 4262bab4e8648c660ecffd517bbb38ed446ad0ca
Author: eric at webkit.org <eric at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Fri Feb 19 22:34:55 2010 +0000

    2010-02-19  James Hawkins  <jhawkins at chromium.org>
    
            Reviewed by Eric Seidel.
    
            [Chromium] Rename EditorClientImpl::onAutofillSuggestionAccepted to
            onAutocompleteSuggestionAccepted to better match the purpose of the
            function.
    
            https://bugs.webkit.org/show_bug.cgi?id=35171
    
            * src/EditorClientImpl.cpp:
            (WebKit::EditorClientImpl::onAutocompleteSuggestionAccepted):
            * src/EditorClientImpl.h:
            * src/SuggestionsPopupMenuClient.cpp:
            (WebKit::SuggestionsPopupMenuClient::valueChanged):
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@55031 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/chromium/ChangeLog b/WebKit/chromium/ChangeLog
index 0869387..18deb21 100644
--- a/WebKit/chromium/ChangeLog
+++ b/WebKit/chromium/ChangeLog
@@ -1,3 +1,19 @@
+2010-02-19  James Hawkins  <jhawkins at chromium.org>
+
+        Reviewed by Eric Seidel.
+
+        [Chromium] Rename EditorClientImpl::onAutofillSuggestionAccepted to
+        onAutocompleteSuggestionAccepted to better match the purpose of the
+        function.
+
+        https://bugs.webkit.org/show_bug.cgi?id=35171
+
+        * src/EditorClientImpl.cpp:
+        (WebKit::EditorClientImpl::onAutocompleteSuggestionAccepted):
+        * src/EditorClientImpl.h:
+        * src/SuggestionsPopupMenuClient.cpp:
+        (WebKit::SuggestionsPopupMenuClient::valueChanged):
+
 2010-02-18  Peter Kasting  <pkasting at google.com>
 
         Reviewed by Darin Fisher.
diff --git a/WebKit/chromium/src/EditorClientImpl.cpp b/WebKit/chromium/src/EditorClientImpl.cpp
index d5bddc5..cfd8ec4 100644
--- a/WebKit/chromium/src/EditorClientImpl.cpp
+++ b/WebKit/chromium/src/EditorClientImpl.cpp
@@ -784,7 +784,7 @@ void EditorClientImpl::cancelPendingAutofill()
     m_autofillTimer.stop();
 }
 
-void EditorClientImpl::onAutofillSuggestionAccepted(HTMLInputElement* textField)
+void EditorClientImpl::onAutocompleteSuggestionAccepted(HTMLInputElement* textField)
 {
     WebFrameImpl* webframe = WebFrameImpl::fromFrame(textField->document()->frame());
     if (!webframe)
diff --git a/WebKit/chromium/src/SuggestionsPopupMenuClient.cpp b/WebKit/chromium/src/SuggestionsPopupMenuClient.cpp
index b4a77a3..aaf9036 100644
--- a/WebKit/chromium/src/SuggestionsPopupMenuClient.cpp
+++ b/WebKit/chromium/src/SuggestionsPopupMenuClient.cpp
@@ -65,7 +65,7 @@ void SuggestionsPopupMenuClient::valueChanged(unsigned listIndex, bool fireEvent
     EditorClientImpl* editor =
         static_cast<EditorClientImpl*>(webView->page()->editorClient());
     ASSERT(editor);
-    editor->onAutofillSuggestionAccepted(
+    editor->onAutocompleteSuggestionAccepted(
         static_cast<HTMLInputElement*>(m_textField.get()));
 }
 

diff --git a/WebKit/chromium/src/EditorClientImpl.h b/WebKit/chromium/src/EditorClientImpl.h
index fd08b4d..006b609 100644
--- a/WebKit/chromium/src/EditorClientImpl.h
+++ b/WebKit/chromium/src/EditorClientImpl.h
@@ -118,10 +118,10 @@ public:
     virtual bool showFormAutofillForNode(WebCore::Node*);
 
     // Notification that the text changed due to acceptance of a suggestion
     // provided by an autofill popup.  Having a separate callback in this case
     // is a simple way to break the cycle that would otherwise occur if
     // textDidChangeInTextField was called.
-    virtual void onAutofillSuggestionAccepted(WebCore::HTMLInputElement*);
+    virtual void onAutocompleteSuggestionAccepted(WebCore::HTMLInputElement*);
 
 private:
     void modifySelection(WebCore::Frame*, WebCore::KeyboardEvent*);
@@ -118,10 +118,10 @@ public:
 
     // Notification that the text changed due to acceptance of a suggestion
-    // provided by an autofill popup.  Having a separate callback in this case
-    // is a simple way to break the cycle that would otherwise occur if
+    // provided by an Autocomplete popup.  Having a separate callback in this
+    // case is a simple way to break the cycle that would otherwise occur if
     // textDidChangeInTextField was called.
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list